@@ -16,11 +16,13 @@
 # specific language governing permissions and limitations
 # under the License.
 
-from typing import Dict, List, Union
+from typing import TYPE_CHECKING, List, Sequence, Union
 
 from airflow.providers.redis.hooks.redis import RedisHook
 from airflow.sensors.base import BaseSensorOperator
-from airflow.utils.decorators import apply_defaults
+
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
 
 
 class RedisPubSubSensor(BaseSensorOperator):
@@ -28,15 +30,12 @@ class RedisPubSubSensor(BaseSensorOperator):
     Redis sensor for reading a message from pub sub channels
 
     :param channels: The channels to be subscribed to (templated)
-    :type channels: str or list of str
     :param redis_conn_id: the redis connection id
-    :type redis_conn_id: str
     """
 
-    template_fields = ('channels',)
+    template_fields: Sequence[str] = ('channels',)
     ui_color = '#f0eee4'
 
-    @apply_defaults
     def __init__(self, *, channels: Union[List[str], str], redis_conn_id: str, **kwargs) -> None:
         super().__init__(**kwargs)
         self.channels = channels
@@ -44,14 +43,13 @@ class RedisPubSubSensor(BaseSensorOperator):
         self.pubsub = RedisHook(redis_conn_id=self.redis_conn_id).get_conn().pubsub()
         self.pubsub.subscribe(self.channels)
 
-    def poke(self, context: Dict) -> bool:
+    def poke(self, context: 'Context') -> bool:
         """
         Check for message on subscribed channels and write to xcom the message with key ``message``
 
         An example of message ``{'type': 'message', 'pattern': None, 'channel': b'test', 'data': b'hello'}``
 
         :param context: the context object
-        :type context: dict
         :return: ``True`` if message (with type 'message') is available or ``False`` if not
         """
         self.log.info('RedisPubSubSensor checking for message on channels: %s', self.channels)
